==> haskell-constraints-0.14.2-77-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints
version:              0.14.2
visibility:           public
id:                   constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
key:                  constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2021 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  7d8676ec33710a2bed93105cb460d403
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Char Data.Constraint.Deferrable
    Data.Constraint.Forall Data.Constraint.Lifting Data.Constraint.Nat
    Data.Constraint.Symbol Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/constraints-0.14.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/constraints-0.14.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/constraints-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints
hs-libraries:         HSconstraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
depends:
    base-4.18.2.1 binary-0.8.9.1 boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
    deepseq-1.4.8.1 ghc-prim-0.10.0
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z mtl-2.3.1
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.14.2-79-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints
version:              0.14.2
visibility:           public
id:                   constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
key:                  constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2021 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  190df87b361656c224cfa6078cc4490a
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Char Data.Constraint.Deferrable
    Data.Constraint.Forall Data.Constraint.Lifting Data.Constraint.Nat
    Data.Constraint.Symbol Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/constraints-0.14.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/constraints-0.14.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/constraints-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints
hs-libraries:         HSconstraints-0.14.2-HITsp0guL9Z2vC96u1IEz
depends:
    base-4.18.2.1 binary-0.8.9.1 boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
    deepseq-1.4.8.1 ghc-prim-0.10.0
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD mtl-2.3.1
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
